@@ -8,6 +8,7 @@
 
 #include <sys/types.h>
 #include <sys/stat.h>
+#include <sys/sysinfo.h>
 
 #include <stdio.h>
 #include <string.h>
@@ -67,7 +68,9 @@
 #define CFG_ALPN_PROTOS "alpn-protos"
 #define CFG_PARAM_ALPN_PROTOS 48173
 #define CFG_BACKEND_CONNECT_TIMEOUT "backend-connect-timeout"
+#define CFG_PARAM_BACKEND_CONNECT_TIMEOUT 48174
 #define CFG_SSL_HANDSHAKE_TIMEOUT "ssl-handshake-timeout"
+#define CFG_PARAM_SSL_HANDSHAKE_TIMEOUT 48175
 #define CFG_RECV_BUFSIZE "recv-bufsize"
 #define CFG_SEND_BUFSIZE "send-bufsize"
 #define CFG_LOG_FILENAME "log-filename"
@@ -356,28 +359,48 @@ config_param_val_bool(char *val, int *res)
 }
 
 static int
-config_param_uds(const char *str, char **path)
+config_uds_verify(hitch_config *cfg)
 {
 	struct stat st;
+	struct vsb *vsb;
+	int ret = 0;
+	char *s;
 
-	AN(path);
-
-	if (strlen(str) > 104) {
-		config_error_set("UNIX domain socket path too long.");
+	if (!cfg->BACK_PATH)
 		return (0);
+
+	s = strdup(cfg->BACK_PATH);
+	if (cfg->CHROOT && *cfg->CHROOT) {
+		vsb = VSB_new_auto();
+		AN(vsb);
+		VSB_cat(vsb, cfg->CHROOT);
+		if (cfg->CHROOT[strlen(cfg->CHROOT) - 1] != '/' &&
+		    cfg->BACK_PATH[0] != '/')
+			VSB_cat(vsb, "/");
+		VSB_cat(vsb, cfg->BACK_PATH);
+		AZ(VSB_finish(vsb));
+		REPLACE(s, VSB_data(vsb));
+		VSB_delete(vsb);
 	}
 
-	if (stat(str, &st)) {
-		config_error_set("Unable to stat path '%s': %s", str,
+	if (stat(s, &st)) {
+		config_error_set("Unable to stat path '%s': %s", s,
 		    strerror(errno));
-		return (0);
+		ret = 1;
+	} else if (!S_ISSOCK(st.st_mode)) {
+		config_error_set("Invalid path '%s': Not a socket.",
+		    s);
+		ret = 1;
 	}
 
-	if (!S_ISSOCK(st.st_mode)) {
-		config_error_set("Invalid path '%s': Not a socket.", str);
-		return (0);
-	}
+	free(s);
+	return (ret);
+}
 
+static int
+config_param_uds(const char *str, char **path)
+{
+	AN(path);
 	*path = strdup(str);
 	return (1);
 }
@@ -543,6 +566,25 @@ config_param_val_long(char *str, long *dst, int non_negative)
 	return (1);
 }
 
+static int
+config_param_val_workers(char *str, long *dst, int non_negative)
+{
+	assert(str != NULL);
+
+	if (strcasecmp(str, "auto") == 0) {
+#if SC_NPROCESSORS_ONLN_WORKS
+		/* Get number of active CPU */
+		*dst = sysconf(_SC_NPROCESSORS_ONLN);
+#else
+		*dst = 1;
+		fprintf(stderr, "Warning: could not determine number of active CPU."
+			" Defaulting to 1 single worker.\n");
+#endif
+		return (1);
+	}
+	return config_param_val_long(str, dst, non_negative);
+}
+
 static double
 mtim2double(const struct stat *sb)
 {
@@ -563,6 +605,7 @@ cfg_cert_file_new(void)
 	ALLOC_OBJ(cert, CFG_CERT_FILE_MAGIC);
 	AN(cert);
 	cert->ocsp_vfy = -1;
+	cert->client_verify = -1;
 	return (cert);
 }
 
@@ -575,6 +618,7 @@ cfg_cert_file_free(struct cfg_cert_file **cfptr)
 	cf = *cfptr;
 	free(cf->filename);
 	free(cf->ocspfn);
+	free(cf->client_verify_ca);
 	FREE_OBJ(cf);
 	*cfptr = NULL;
 }
@@ -637,6 +681,27 @@ cfg_cert_vfy(struct cfg_cert_file *cf)
 		d = mtim2double(&st);
 		cf->mtim = cf->mtim > d ? cf->mtim : d;
 	}
+
+	if (cf->client_verify != -1) {
+		if (cf->client_verify_ca == NULL) {
+			config_error_set("Setting 'client-verify-ca' is "
+			    "required when configuring client-verify");
+			return (0);
+		}
+
+		if (stat(cf->client_verify_ca, &st) != 0) {
+			config_error_set("Unable to stat client_verify_ca file "
+			    "'%s': %s", cf->client_verify_ca,
+			    strerror(errno));
+			return (0);
+		}
+
+		if (!S_ISREG(st.st_mode)) {
+			config_error_set("Invalid client_verify_ca file "
+			    "'%s': Not a file.", cf->priv_key_filename);
+			return (0);
+		}
+	}
 	return (1);
 }
 
@@ -893,7 +958,7 @@ config_param_validate(const char *k, char *v, hitch_config *cfg,
 		r = config_param_host_port(v, &cfg->BACK_IP, &cfg->BACK_PORT,
 		    &cfg->BACK_PATH);
 	} else if (strcmp(k, CFG_WORKERS) == 0) {
-		r = config_param_val_long(v, &cfg->NCORES, 1);
+		r = config_param_val_workers(v, &cfg->NCORES, 1);
 	} else if (strcmp(k, CFG_BACKLOG) == 0) {
 		r = config_param_val_int(v, &cfg->BACKLOG, 0);
 	} else if (strcmp(k, CFG_KEEPALIVE) == 0) {
@@ -1305,6 +1370,12 @@ config_print_usage_fd(char *prog, FILE *out)
 	fprintf(out, "\t--send-bufsize=SIZE\n");
 	fprintf(out, "\t\tSend buffer size on client socket (Default: %d)\n",
 	    cfg->SEND_BUFSIZE);
+	fprintf(out, "\t--backend-connect-timeout=SECS\n");
+	fprintf(out, "\t\tBackend connect timeout (Default: %d)\n",
+	    cfg->BACKEND_CONNECT_TIMEOUT);
+	fprintf(out, "\t--ssl-handshake-timeout=SECS\n");
+	fprintf(out, "\t\tTLS handshake timeout (Default: %d)\n",
+	    cfg->SSL_HANDSHAKE_TIMEOUT);
 
 #ifdef USE_SHARED_CACHE
 	fprintf(out, "\n");
@@ -1548,6 +1619,10 @@ config_parse_cli(int argc, char **argv, hitch_config *cfg)
 		{ CFG_OCSP_DIR, 1, NULL, 'o' },
 		{ CFG_TLS_PROTOS, 1, NULL, CFG_PARAM_TLS_PROTOS },
 		{ CFG_DBG_LISTEN, 1, NULL, CFG_PARAM_DBG_LISTEN },
+		{ CFG_BACKEND_CONNECT_TIMEOUT, 1, NULL,
+		  CFG_PARAM_BACKEND_CONNECT_TIMEOUT},
+		{ CFG_SSL_HANDSHAKE_TIMEOUT, 1, NULL,
+		  CFG_PARAM_SSL_HANDSHAKE_TIMEOUT},
 		{ "test", 0, NULL, 't' },
 		{ "version", 0, NULL, 'V' },
 		{ "help", 0, NULL, 'h' },
@@ -1618,6 +1693,8 @@ CFG_ARG(CFG_PARAM_RECV_BUFSIZE, CFG_RECV_BUFSIZE);
 CFG_ARG(CFG_PARAM_ALPN_PROTOS, CFG_ALPN_PROTOS);
 CFG_ARG(CFG_PARAM_TLS_PROTOS, CFG_TLS_PROTOS);
 CFG_ARG(CFG_PARAM_DBG_LISTEN, CFG_DBG_LISTEN);
+CFG_ARG(CFG_PARAM_BACKEND_CONNECT_TIMEOUT, CFG_BACKEND_CONNECT_TIMEOUT);
+CFG_ARG(CFG_PARAM_SSL_HANDSHAKE_TIMEOUT, CFG_SSL_HANDSHAKE_TIMEOUT);
 CFG_ARG('c', CFG_CIPHERS);
 CFG_ARG('e', CFG_SSL_ENGINE);
 CFG_ARG('b', CFG_BACKEND);
@@ -1834,5 +1911,8 @@ CFG_BOOL('s', CFG_SYSLOG);
 		}
 	}
 
+	if (config_uds_verify(cfg))
+		return (1);
+
 	return (0);
 }
