@@ -15,7 +15,7 @@ EOF
 start_hitch --config=$PWD/hitch.cfg
 
 s_client >s_client1.dump
-subj_name_eq "default.example.com" s_client1.dump
+subject_field_eq CN "default.example.com" s_client1.dump
 
 # restart hitch after having a more recent cert file
 cp ${CERTSDIR}/ecc.example.com.pem cert.pem
@@ -24,4 +24,4 @@ kill -HUP $(hitch_pid)
 sleep 2
 
 s_client | tee s_client2.dump
-subj_name_eq "ecc.example.com" s_client2.dump
+subject_field_eq CN "ecc.example.com" s_client2.dump
